==> haskell-configurator-pg-0.2.11-2.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-configurator-pg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 configurator-pg
version:              0.2.11
visibility:           public
id:                   configurator-pg-0.2.11-IHuq5ZDrGHcBrclCBJi8hS
key:                  configurator-pg-0.2.11-IHuq5ZDrGHcBrclCBJi8hS
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2011-2014 Bryan O'\''Sullivan
    Copyright 2015-2016 Leon P Smith
    Copyright 2019-2022 Robert Vollmert

maintainer:           rob@vllmrt.net
author:               Robert Vollmert
homepage:             https://github.com/robx/configurator-pg
synopsis:             Reduced parser for configurator-ng config files
description:
    This module provides a simplified and updated interface to the
    configuration file format of
    <https://hackage.haskell.org/package/configurator configurator> and
    <https://hackage.haskell.org/package/configurator-ng configurator-ng>.
    Its aim is primarily to allow updating programs that depend on
    configurator-ng to new versions of GHC without changing the
    configuration file format.

category:             Configuration, Data
abi:                  f052ea9e7f96269468c022c8355bd8fe
exposed:              True
exposed-modules:      Data.Configurator
hidden-modules:
    Data.Configurator.Load Data.Configurator.Parser
    Data.Configurator.Syntax Data.Configurator.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/configurator-pg-0.2.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/configurator-pg-0.2.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/configurator-pg-0.2.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configurator-pg
hs-libraries:         HSconfigurator-pg-0.2.11-IHuq5ZDrGHcBrclCBJi8hS
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    megaparsec-9.7.0-Fzm61TdpQu7Cpey7aoa8J9
    protolude-0.3.5-7SWbne44JkdFiBIH3eNLnc
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-configurator-pg/html/configurator-pg.haddock

haddock-html:         /usr/share/doc/haskell-configurator-pg/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configurator-pg-0.2.11-3-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-configurator-pg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 configurator-pg
version:              0.2.11
visibility:           public
id:                   configurator-pg-0.2.11-3RMnKtFMdwvFKQpX4kWTYs
key:                  configurator-pg-0.2.11-3RMnKtFMdwvFKQpX4kWTYs
license:              BSD-3-Clause
copyright:
    Copyright 2011 MailRank, Inc.
    Copyright 2011-2014 Bryan O'\''Sullivan
    Copyright 2015-2016 Leon P Smith
    Copyright 2019-2022 Robert Vollmert

maintainer:           rob@vllmrt.net
author:               Robert Vollmert
homepage:             https://github.com/robx/configurator-pg
synopsis:             Reduced parser for configurator-ng config files
description:
    This module provides a simplified and updated interface to the
    configuration file format of
    <https://hackage.haskell.org/package/configurator configurator> and
    <https://hackage.haskell.org/package/configurator-ng configurator-ng>.
    Its aim is primarily to allow updating programs that depend on
    configurator-ng to new versions of GHC without changing the
    configuration file format.

category:             Configuration, Data
abi:                  897eb2464118b37ec084fcc7ba1ec5f6
exposed:              True
exposed-modules:      Data.Configurator
hidden-modules:
    Data.Configurator.Load Data.Configurator.Parser
    Data.Configurator.Syntax Data.Configurator.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/configurator-pg-0.2.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/configurator-pg-0.2.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/configurator-pg-0.2.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-configurator-pg
hs-libraries:         HSconfigurator-pg-0.2.11-3RMnKtFMdwvFKQpX4kWTYs
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    megaparsec-9.7.0-CJUMznUvVaqA9LkZfHNyDE
    protolude-0.3.5-8b84v0Z1fvfD2c2SvK9yLZ
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-configurator-pg/html/configurator-pg.haddock

haddock-html:         /usr/share/doc/haskell-configurator-pg/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
